@@ -42,7 +42,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -72,7 +72,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @r#"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -82,15 +82,15 @@ mod tests {
           | ^^ Clicking here
           |
         info: Found 1 type definition
-           --> stdlib/typing.pyi:351:1
+           --> stdlib/typing.pyi:487:1
             |
-        349 | Final: _SpecialForm
-        350 |
-        351 | Literal: _SpecialForm
+        485 | """
+        486 |
+        487 | Literal: _SpecialForm
             | -------
-        352 | TypedDict: _SpecialForm
+        488 | """Special typing form to define literal types (a.k.a. value types).
             |
-        ");
+        "#);
     }
 
     // this is a slightly different case to the one above,
@@ -137,7 +137,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @r#"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -147,16 +147,15 @@ mod tests {
           | ^^ Clicking here
           |
         info: Found 1 type definition
-           --> stdlib/typing.pyi:781:1
-            |
-        779 |         def __class_getitem__(cls, args: TypeVar | tuple[TypeVar, ...]) -> _Final: ...
-        780 |
-        781 | Generic: type[_Generic]
-            | -------
-        782 |
-        783 | class _ProtocolMeta(ABCMeta):
-            |
-        ");
+            --> stdlib/typing.pyi:1268:1
+             |
+        1266 |         def __class_getitem__(cls, args: TypeVar | tuple[TypeVar, ...]) -> _Final: ...
+        1267 |
+        1268 | Generic: type[_Generic]
+             | -------
+        1269 | """Abstract base class for generic types.
+             |
+        "#);
     }
 
     #[test]
@@ -169,7 +168,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -179,13 +178,13 @@ mod tests {
           | ^^ Clicking here
           |
         info: Found 1 type definition
-          --> stdlib/ty_extensions.pyi:21:1
+          --> stdlib/ty_extensions.pyi:15:1
            |
-        19 | # Types
-        20 | Unknown = object()
-        21 | AlwaysTruthy = object()
+        13 | # Types
+        14 | Unknown = object()
+        15 | AlwaysTruthy = object()
            | ------------
-        22 | AlwaysFalsy = object()
+        16 | AlwaysFalsy = object()
            |
         ");
     }
@@ -202,7 +201,7 @@ mod tests {
         "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:6:1
           |
@@ -240,7 +239,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
           --> main.py:12:1
            |
@@ -273,7 +272,7 @@ mod tests {
 
         test.write_file("lib.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:8
           |
@@ -300,7 +299,7 @@ mod tests {
         test.write_file("lib/__init__.py", "b = 7").unwrap();
         test.write_file("lib/submod.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:8
           |
@@ -327,7 +326,7 @@ mod tests {
         test.write_file("lib/__init__.py", "b = 7").unwrap();
         test.write_file("lib/submod.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:12
           |
@@ -353,7 +352,7 @@ mod tests {
 
         test.write_file("lib.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:6
           |
@@ -380,7 +379,7 @@ mod tests {
         test.write_file("lib/__init__.py", "b = 7").unwrap();
         test.write_file("lib/submod.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:6
           |
@@ -407,7 +406,7 @@ mod tests {
         test.write_file("lib/__init__.py", "b = 7").unwrap();
         test.write_file("lib/submod.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:10
           |
@@ -443,7 +442,7 @@ mod tests {
         test.write_file("lib/sub/bot/botmod.py", "botmod = 31")
             .unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> lib/sub/__init__.py:2:11
           |
@@ -480,7 +479,7 @@ mod tests {
         test.write_file("lib/sub/bot/botmod.py", "botmod = 31")
             .unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> lib/sub/__init__.py:2:7
           |
@@ -517,7 +516,7 @@ mod tests {
         test.write_file("lib/sub/bot/botmod.py", "botmod = 31")
             .unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> lib/sub/__init__.py:2:7
           |
@@ -569,7 +568,7 @@ mod tests {
 
         test.write_file("lib.py", "a = 10").unwrap();
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -652,7 +651,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:34
           |
@@ -676,7 +675,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:41
           |
@@ -797,13 +796,13 @@ mod tests {
             |       -------
           5 |     """some docs"""
             |
-           ::: stdlib/types.pyi:950:11
+           ::: stdlib/types.pyi:974:11
             |
-        948 | if sys.version_info >= (3, 10):
-        949 |     @final
-        950 |     class NoneType:
+        972 | if sys.version_info >= (3, 10):
+        973 |     @final
+        974 |     class NoneType:
             |           --------
-        951 |         """The type of the None singleton."""
+        975 |         """The type of the None singleton."""
             |
         "#);
     }
@@ -851,13 +850,13 @@ mod tests {
             |       -------
           5 |     """some docs"""
             |
-           ::: stdlib/types.pyi:950:11
+           ::: stdlib/types.pyi:974:11
             |
-        948 | if sys.version_info >= (3, 10):
-        949 |     @final
-        950 |     class NoneType:
+        972 | if sys.version_info >= (3, 10):
+        973 |     @final
+        974 |     class NoneType:
             |           --------
-        951 |         """The type of the None singleton."""
+        975 |         """The type of the None singleton."""
             |
         "#);
     }
@@ -883,13 +882,13 @@ mod tests {
         4 | class MyClass:
           |
         info: Found 1 type definition
-          --> stdlib/ty_extensions.pyi:20:1
+          --> stdlib/ty_extensions.pyi:14:1
            |
-        19 | # Types
-        20 | Unknown = object()
+        13 | # Types
+        14 | Unknown = object()
            | -------
-        21 | AlwaysTruthy = object()
-        22 | AlwaysFalsy = object()
+        15 | AlwaysTruthy = object()
+        16 | AlwaysFalsy = object()
            |
         "#);
     }
@@ -938,13 +937,13 @@ mod tests {
           |      ^^ Clicking here
           |
         info: Found 1 type definition
-          --> stdlib/ty_extensions.pyi:20:1
+          --> stdlib/ty_extensions.pyi:14:1
            |
-        19 | # Types
-        20 | Unknown = object()
+        13 | # Types
+        14 | Unknown = object()
            | -------
-        21 | AlwaysTruthy = object()
-        22 | AlwaysFalsy = object()
+        15 | AlwaysTruthy = object()
+        16 | AlwaysFalsy = object()
            |
         "#);
     }
@@ -965,13 +964,13 @@ mod tests {
           |     ^^^^^^ Clicking here
           |
         info: Found 1 type definition
-          --> stdlib/ty_extensions.pyi:20:1
+          --> stdlib/ty_extensions.pyi:14:1
            |
-        19 | # Types
-        20 | Unknown = object()
+        13 | # Types
+        14 | Unknown = object()
            | -------
-        21 | AlwaysTruthy = object()
-        22 | AlwaysFalsy = object()
+        15 | AlwaysTruthy = object()
+        16 | AlwaysFalsy = object()
            |
         "#);
     }
@@ -1166,7 +1165,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:13
           |
@@ -1190,7 +1189,7 @@ mod tests {
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:2:37
           |
@@ -1339,13 +1338,13 @@ f(**kwargs<CURSOR>)
           |     ^^^^^^ Clicking here
           |
         info: Found 1 type definition
-            --> stdlib/builtins.pyi:2920:7
+            --> stdlib/builtins.pyi:2947:7
              |
-        2919 | @disjoint_base
-        2920 | class dict(MutableMapping[_KT, _VT]):
+        2946 | @disjoint_base
+        2947 | class dict(MutableMapping[_KT, _VT]):
              |       ----
-        2921 |     """dict() -> new empty dictionary
-        2922 |     dict(mapping) -> new dictionary initialized from a mapping object's
+        2948 |     """dict() -> new empty dictionary
+        2949 |     dict(mapping) -> new dictionary initialized from a mapping object's
              |
         "#);
     }
@@ -1504,7 +1503,7 @@ def function():
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:7:1
           |
@@ -1533,7 +1532,7 @@ def function():
             "#,
         );
 
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> main.py:4:1
           |
@@ -1610,13 +1609,13 @@ def function():
         916 |     """str(object='') -> str
         917 |     str(bytes_or_buffer[, encoding[, errors]]) -> str
             |
-           ::: stdlib/types.pyi:950:11
+           ::: stdlib/types.pyi:974:11
             |
-        948 | if sys.version_info >= (3, 10):
-        949 |     @final
-        950 |     class NoneType:
+        972 | if sys.version_info >= (3, 10):
+        973 |     @final
+        974 |     class NoneType:
             |           --------
-        951 |         """The type of the None singleton."""
+        975 |         """The type of the None singleton."""
             |
         "#);
     }
@@ -1642,7 +1641,7 @@ def function():
             .build();
 
         // The module is the correct type definition
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> mypackage/__init__.py:4:5
           |
@@ -1679,7 +1678,7 @@ def function():
             .build();
 
         // The module is the correct type definition
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> mypackage/__init__.py:2:7
           |
@@ -1716,7 +1715,7 @@ def function():
             .build();
 
         // Unknown is correct, `submod` is not in scope
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> mypackage/__init__.py:4:5
           |
@@ -1726,13 +1725,13 @@ def function():
           |     ^^^^^^ Clicking here
           |
         info: Found 1 type definition
-          --> stdlib/ty_extensions.pyi:20:1
+          --> stdlib/ty_extensions.pyi:14:1
            |
-        19 | # Types
-        20 | Unknown = object()
+        13 | # Types
+        14 | Unknown = object()
            | -------
-        21 | AlwaysTruthy = object()
-        22 | AlwaysFalsy = object()
+        15 | AlwaysTruthy = object()
+        16 | AlwaysFalsy = object()
            |
         ");
     }
@@ -1758,7 +1757,7 @@ def function():
             .build();
 
         // The module is correct
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> mypackage/__init__.py:2:14
           |
@@ -1797,7 +1796,7 @@ def function():
             .build();
 
         // The module is correct
-        assert_snapshot!(test.goto_type_definition(), @r"
+        assert_snapshot!(test.goto_type_definition(), @"
         info[goto-type definition]: Go to type definition
          --> mypackage/__init__.py:2:7
           |
