@@ -29,10 +29,11 @@ use ruff_python_ast::visitor::source_order::{SourceOrderVisitor, TraversalSignal
 use ruff_python_codegen::Stylist;
 use ruff_python_importer::Insertion;
 use ruff_text_size::{Ranged, TextRange, TextSize};
+use ty_module_resolver::ModuleName;
 use ty_project::Db;
 use ty_python_semantic::semantic_index::definition::DefinitionKind;
 use ty_python_semantic::types::Type;
-use ty_python_semantic::{MemberDefinition, ModuleName, SemanticModel};
+use ty_python_semantic::{MemberDefinition, SemanticModel};
 
 pub(crate) struct Importer<'a> {
     /// The ty Salsa database.
@@ -880,10 +881,10 @@ mod tests {
     use ruff_python_codegen::Stylist;
     use ruff_python_trivia::textwrap::dedent;
     use ruff_text_size::TextSize;
+    use ty_module_resolver::SearchPathSettings;
     use ty_project::ProjectMetadata;
     use ty_python_semantic::{
-        Program, ProgramSettings, PythonPlatform, PythonVersionWithSource, SearchPathSettings,
-        SemanticModel,
+        Program, ProgramSettings, PythonPlatform, PythonVersionWithSource, SemanticModel,
     };
 
     use super::*;
@@ -949,7 +950,7 @@ mod tests {
     fn empty_source_qualified() {
         let test = cursor_test("<CURSOR>");
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         collections.defaultdict
         ");
@@ -959,7 +960,7 @@ mod tests {
     fn empty_source_unqualified() {
         let test = cursor_test("<CURSOR>");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         defaultdict
         ");
@@ -974,7 +975,7 @@ import collections
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         collections.defaultdict
         ");
@@ -989,7 +990,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         defaultdict
         ");
@@ -1004,7 +1005,7 @@ from collections import *
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import *
         defaultdict
         ");
@@ -1019,7 +1020,7 @@ import collections as c
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections as c
         c.defaultdict
         ");
@@ -1034,7 +1035,7 @@ from collections import defaultdict as ddict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict as ddict
         ddict
         ");
@@ -1049,7 +1050,7 @@ from collections import Counter
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import Counter, defaultdict
         defaultdict
         ");
@@ -1064,7 +1065,7 @@ from collections import Counter as C
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import Counter as C, defaultdict
         defaultdict
         ");
@@ -1079,7 +1080,7 @@ from collections import Counter, OrderedDict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import Counter, OrderedDict, defaultdict
         defaultdict
         ");
@@ -1094,7 +1095,7 @@ from collections import Counter as C, OrderedDict as OD
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import Counter as C, OrderedDict as OD, defaultdict
         defaultdict
         ");
@@ -1109,7 +1110,7 @@ from collections import Counter;
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import Counter, defaultdict;
         defaultdict
         ");
@@ -1141,7 +1142,7 @@ from collections import (Counter)
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import (Counter, defaultdict)
         defaultdict
         ");
@@ -1156,7 +1157,7 @@ from collections import (Counter,)
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import (Counter, defaultdict,)
         defaultdict
         ");
@@ -1174,7 +1175,7 @@ from collections import (
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import (
             Counter,
             OrderedDict, defaultdict,
@@ -1195,7 +1196,7 @@ from collections import (
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import (
             Counter,
             OrderedDict, defaultdict
@@ -1215,7 +1216,7 @@ from collections import (
             )
             .build();
         assert_snapshot!(
-            test.import("package.foo", "Bar"), @r"
+            test.import("package.foo", "Bar"), @"
         from ...foo import Foo, Bar
         Bar
         ");
@@ -1230,7 +1231,7 @@ from collections import
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         defaultdict
         ");
@@ -1251,7 +1252,7 @@ from collections import ()
         // always be some cases like this that won't make
         // sense.
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import ()
         from collections import defaultdict
         defaultdict
@@ -1269,7 +1270,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         import re
         from collections import defaultdict
@@ -1288,7 +1289,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         import re
         defaultdict
@@ -1306,7 +1307,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         from collections import defaultdict
         defaultdict
@@ -1323,7 +1324,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import OrderedDict
         from collections import defaultdict
         defaultdict
@@ -1340,7 +1341,7 @@ import collections
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import OrderedDict, defaultdict
         import collections
         defaultdict
@@ -1359,13 +1360,13 @@ from collections import defaultdict
         // we add another import at the top-level
         // of the module.
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         collections.defaultdict
         from collections import defaultdict
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         defaultdict
         from collections import defaultdict
@@ -1385,7 +1386,7 @@ from collections import defaultdict
         // we add another import at the top-level
         // of the module.
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         def foo():
             collections.defaultdict
@@ -1404,7 +1405,7 @@ def foo():
         ",
         );
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
 
         def foo():
@@ -1422,7 +1423,7 @@ from __future__ import annotations
         ",
         );
         assert_snapshot!(
-            test.import("typing", "TypeVar"), @r"
+            test.import("typing", "TypeVar"), @"
         from __future__ import annotations
         import typing
 
@@ -1442,6 +1443,7 @@ from __future__ import annotations
         );
         assert_snapshot!(
             test.import("typing", "TypeVar"), @r#"
+
         "This is a module level docstring"
         from __future__ import annotations
         import typing
@@ -1460,13 +1462,13 @@ defaultdict = 1
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         defaultdict = 1
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         defaultdict = 1
         (collections.defaultdict)
@@ -1483,13 +1485,13 @@ collections = 1
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         collections = 1
         (defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         collections = 1
         (defaultdict)
@@ -1525,14 +1527,14 @@ defaultdict = 2
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         collections = 1
         defaultdict = 2
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         collections = 1
         defaultdict = 2
@@ -1550,13 +1552,13 @@ def foo():
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         def foo():
             (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         def foo():
             (defaultdict)
@@ -1573,13 +1575,13 @@ def defaultdict():
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         def defaultdict():
             (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         def defaultdict():
             (collections.defaultdict)
@@ -1596,13 +1598,13 @@ def collections():
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         def collections():
             (defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         def collections():
             (defaultdict)
@@ -1620,14 +1622,14 @@ import defaultdict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         import defaultdict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         import defaultdict
 
@@ -1646,14 +1648,14 @@ from foo import collections
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         from collections import defaultdict
         from foo import collections
 
         (defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         from foo import collections
 
@@ -1672,14 +1674,14 @@ from othermodule import defaultdict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         from othermodule import defaultdict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         from othermodule import defaultdict
 
@@ -1698,14 +1700,14 @@ import defaultdict as ddict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         import defaultdict as ddict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         import defaultdict as ddict
 
@@ -1724,14 +1726,14 @@ from othermodule import something as defaultdict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         from othermodule import something as defaultdict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         import collections
         from othermodule import something as defaultdict
 
@@ -1750,14 +1752,14 @@ import defaultdict as ddict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         import defaultdict as ddict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         import defaultdict as ddict
 
@@ -1776,14 +1778,14 @@ from foo import defaultdict as ddict
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         from foo import defaultdict as ddict
 
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         from foo import defaultdict as ddict
 
@@ -1806,7 +1808,7 @@ import numpy as np
         );
 
         assert_snapshot!(
-            test.import("collections", "defaultdict"), @r"
+            test.import("collections", "defaultdict"), @"
         import collections
         import json
         import re
@@ -1817,7 +1819,7 @@ import numpy as np
         (collections.defaultdict)
         ");
         assert_snapshot!(
-            test.import_from("collections", "defaultdict"), @r"
+            test.import_from("collections", "defaultdict"), @"
         from collections import defaultdict
         import json
         import re
@@ -1848,7 +1850,7 @@ import numpy as np
             .build();
 
         assert_snapshot!(
-            test.import("foo", "Bar"), @r"
+            test.import("foo", "Bar"), @"
         import foo
         import json
         import re
@@ -1859,7 +1861,7 @@ import numpy as np
         (foo.Bar)
         ");
         assert_snapshot!(
-            test.import_from("foo", "Bar"), @r"
+            test.import_from("foo", "Bar"), @"
         from foo import Bar
         import json
         import re
@@ -2108,7 +2110,7 @@ except ImportError:
             .build();
 
         assert_snapshot!(
-            test.import("quux", "MAGIC"), @r"
+            test.import("quux", "MAGIC"), @"
         import quux
         try:
             from foo import MAGIC
@@ -2118,7 +2120,7 @@ except ImportError:
         (quux.MAGIC)
         ");
         assert_snapshot!(
-            test.import_from("quux", "MAGIC"), @r"
+            test.import_from("quux", "MAGIC"), @"
         import quux
         try:
             from foo import MAGIC
@@ -2153,7 +2155,7 @@ except ImportError:
             .build();
 
         assert_snapshot!(
-            test.import("foo", "MAGIC"), @r"
+            test.import("foo", "MAGIC"), @"
         import foo
         try:
             from foo import MAGIC
@@ -2163,7 +2165,7 @@ except ImportError:
         (foo.MAGIC)
         ");
         assert_snapshot!(
-            test.import_from("foo", "MAGIC"), @r"
+            test.import_from("foo", "MAGIC"), @"
         from foo import MAGIC
         try:
             from foo import MAGIC
@@ -2194,7 +2196,7 @@ except ImportError:
             .build();
 
         assert_snapshot!(
-            test.import("bar", "MAGIC"), @r"
+            test.import("bar", "MAGIC"), @"
         import bar
         try:
             from foo import MAGIC
@@ -2204,7 +2206,7 @@ except ImportError:
         (bar.MAGIC)
         ");
         assert_snapshot!(
-            test.import_from("bar", "MAGIC"), @r"
+            test.import_from("bar", "MAGIC"), @"
         import bar
         try:
             from foo import MAGIC
@@ -2223,7 +2225,7 @@ except ImportError:
         ",
         );
         assert_snapshot!(
-            test.module("collections"), @r"
+            test.module("collections"), @"
         import collections
         collections
         ");
@@ -2238,7 +2240,7 @@ import collections
         ",
         );
         assert_snapshot!(
-            test.module("collections"), @r"
+            test.module("collections"), @"
         import collections
         collections
         ");
@@ -2253,7 +2255,7 @@ from collections import defaultdict
         ",
         );
         assert_snapshot!(
-            test.module("collections"), @r"
+            test.module("collections"), @"
         import collections
         from collections import defaultdict
         collections
@@ -2277,7 +2279,7 @@ from collections import abc
         ",
         );
         assert_snapshot!(
-            test.module("collections.abc"), @r"
+            test.module("collections.abc"), @"
         import collections.abc
         from collections import abc
         collections.abc
