@@ -6,17 +6,20 @@ use itertools::Itertools;
 use ruff_python_ast::name::Name;
 use rustc_hash::FxHashMap;
 
+use crate::types::relation::{HasRelationToVisitor, IsDisjointVisitor, TypeRelation};
 use crate::types::{CallableTypeKind, TypeContext};
 use crate::{
     Db, FxOrderSet,
-    place::{Definedness, Place, PlaceAndQualifiers, place_from_bindings, place_from_declarations},
+    place::{
+        DefinedPlace, Definedness, Place, PlaceAndQualifiers, place_from_bindings,
+        place_from_declarations,
+    },
     semantic_index::{definition::Definition, place::ScopedPlaceId, place_table, use_def_map},
     types::{
         ApplyTypeMappingVisitor, BoundTypeVarInstance, CallableType, ClassBase, ClassLiteral,
-        ClassType, FindLegacyTypeVarsVisitor, HasRelationToVisitor,
-        InstanceFallbackShadowsNonDataDescriptor, IsDisjointVisitor, KnownFunction,
-        MemberLookupPolicy, NormalizedVisitor, PropertyInstanceType, Signature, Type, TypeMapping,
-        TypeQualifiers, TypeRelation, TypeVarVariance, VarianceInferable,
+        ClassType, FindLegacyTypeVarsVisitor, InstanceFallbackShadowsNonDataDescriptor,
+        KnownFunction, MemberLookupPolicy, NormalizedVisitor, PropertyInstanceType, Signature,
+        Type, TypeMapping, TypeQualifiers, TypeVarVariance, VarianceInferable,
         constraints::{ConstraintSet, IteratorConstraintsExtension, OptionConstraintsExtension},
         context::InferContext,
         diagnostic::report_undeclared_protocol_member,
@@ -214,7 +217,7 @@ impl<'db> ProtocolInterface<'db> {
                         db,
                         [Parameter::positional_only(Some(Name::new_static("self")))],
                     ),
-                    Some(ty.normalized(db)),
+                    ty.normalized(db),
                 );
                 let property_getter = Type::single_callable(db, property_getter_signature);
                 let property = PropertyInstanceType::new(db, Some(property_getter), None);
@@ -738,7 +741,11 @@ impl<'a, 'db> ProtocolMember<'a, 'db> {
                 let attribute_type = if self.name == "__call__" {
                     other
                 } else {
-                    let Place::Defined(attribute_type, _, Definedness::AlwaysDefined) = other
+                    let Place::Defined(DefinedPlace {
+                        ty: attribute_type,
+                        definedness: Definedness::AlwaysDefined,
+                        ..
+                    }) = other
                         .invoke_descriptor_protocol(
                             db,
                             self.name,
@@ -783,11 +790,17 @@ impl<'a, 'db> ProtocolMember<'a, 'db> {
             // TODO: consider the types of the attribute on `other` for property members
             ProtocolMemberKind::Property(_) => ConstraintSet::from(matches!(
                 other.member(db, self.name).place,
-                Place::Defined(_, _, Definedness::AlwaysDefined)
+                Place::Defined(DefinedPlace {
+                    definedness: Definedness::AlwaysDefined,
+                    ..
+                })
             )),
             ProtocolMemberKind::Other(member_type) => {
-                let Place::Defined(attribute_type, _, Definedness::AlwaysDefined) =
-                    other.member(db, self.name).place
+                let Place::Defined(DefinedPlace {
+                    ty: attribute_type,
+                    definedness: Definedness::AlwaysDefined,
+                    ..
+                }) = other.member(db, self.name).place
                 else {
                     return ConstraintSet::from(false);
                 };
