@@ -33,6 +33,12 @@ impl BackgroundDocumentRequestHandler for DocumentDiagnosticRequestHandler {
         _client: &Client,
         params: DocumentDiagnosticParams,
     ) -> Result<DocumentDiagnosticReportResult> {
+        if snapshot.global_settings().diagnostic_mode().is_off() {
+            return Ok(DocumentDiagnosticReportResult::Report(
+                DocumentDiagnosticReport::Full(RelatedFullDocumentDiagnosticReport::default()),
+            ));
+        }
+
         let diagnostics = compute_diagnostics(db, snapshot.document(), snapshot.encoding());
 
         let Some(diagnostics) = diagnostics else {
@@ -60,7 +66,11 @@ impl BackgroundDocumentRequestHandler for DocumentDiagnosticRequestHandler {
                         // SAFETY: Pull diagnostic requests are only called for text documents, not for
                         // notebook documents.
                         items: diagnostics
-                            .to_lsp_diagnostics(db, snapshot.resolved_client_capabilities())
+                            .to_lsp_diagnostics(
+                                db,
+                                snapshot.resolved_client_capabilities(),
+                                snapshot.global_settings(),
+                            )
                             .expect_text_document(),
                     },
                 })
