@@ -19,6 +19,7 @@ use serde::{Deserialize, Serialize};
 use ty_project::{ProgressReporter, ProjectDatabase};
 
 use crate::PositionEncoding;
+use crate::capabilities::ResolvedClientCapabilities;
 use crate::document::DocumentKey;
 use crate::server::api::diagnostics::{Diagnostics, to_lsp_diagnostic};
 use crate::server::api::traits::{
@@ -28,7 +29,7 @@ use crate::server::lazy_work_done_progress::LazyWorkDoneProgress;
 use crate::server::{Action, Result};
 use crate::session::client::Client;
 use crate::session::index::Index;
-use crate::session::{SessionSnapshot, SuspendedWorkspaceDiagnosticRequest};
+use crate::session::{GlobalSettings, SessionSnapshot, SuspendedWorkspaceDiagnosticRequest};
 use crate::system::file_to_url;
 
 /// Handler for [Workspace diagnostics](workspace-diagnostics)
@@ -318,10 +319,12 @@ struct ResponseWriter<'a> {
     mode: ReportingMode,
     index: &'a Index,
     position_encoding: PositionEncoding,
+    client_capabilities: ResolvedClientCapabilities,
     // It's important that we use `AnySystemPath` over `Url` here because
     // `file_to_url` isn't guaranteed to return the exact same URL as the one provided
     // by the client.
     previous_result_ids: FxHashMap<DocumentKey, (Url, String)>,
+    global_settings: &'a GlobalSettings,
 }
 
 impl<'a> ResponseWriter<'a> {
@@ -357,7 +360,9 @@ impl<'a> ResponseWriter<'a> {
             mode,
             index,
             position_encoding,
+            client_capabilities: snapshot.resolved_client_capabilities(),
             previous_result_ids,
+            global_settings: snapshot.global_settings(),
         }
     }
 
@@ -406,7 +411,18 @@ impl<'a> ResponseWriter<'a> {
             new_id => {
                 let lsp_diagnostics = diagnostics
                     .iter()
-                    .map(|diagnostic| to_lsp_diagnostic(db, diagnostic, self.position_encoding).1)
+                    .filter_map(|diagnostic| {
+                        Some(
+                            to_lsp_diagnostic(
+                                db,
+                                diagnostic,
+                                self.position_encoding,
+                                self.client_capabilities,
+                                self.global_settings,
+                            )?
+                            .1,
+                        )
+                    })
                     .collect::<Vec<_>>();
 
                 WorkspaceDocumentDiagnosticReport::Full(WorkspaceFullDocumentDiagnosticReport {
